This library aims to provide simple, readable and documented implementations
of commonly taught data structures and algorithms (DSA).
It was created for M269, our DSA course, but we hope it's of use by other courses.